@@ -107,6 +107,7 @@ public interface IManager {
 
     /**
      * @return the created temporary File
+     * @param sourceFileName if source document file name is set then the temp file will be created with this file name within a new folder
      */
-    public File createTempFile(String prefix);
+    public File createTempFile(String prefix, String sourceFileName);
 }
